@@ -1,22 +1,20 @@
 #pragma once
 
-#ifndef FF_INCLUDED_detection_battery_battery
-#define FF_INCLUDED_detection_battery_battery
-
 #include "fastfetch.h"
 
 #define FF_BATTERY_TEMP_UNSET (0/0.0)
 
-typedef struct BatteryResult
+typedef struct FFBatteryResult
 {
     FFstrbuf manufacturer;
+    FFstrbuf manufactureDate;
     FFstrbuf modelName;
     FFstrbuf technology;
-    double capacity;
     FFstrbuf status;
+    FFstrbuf serial;
+    double capacity;
     double temperature;
-} BatteryResult;
+    uint32_t cycleCount;
+} FFBatteryResult;
 
-const char* ffDetectBatteryImpl(FFinstance* instance, FFlist* results);
-
-#endif
+const char* ffDetectBattery(FFBatteryOptions* options, FFlist* results);
